iso_codes = {
 'aa': 'Latn',
 'aar': 'Latn',
 'ab': 'Cyrl',
 'abk': 'Cyrl',
 'abq': 'Cyrl',
 'abr': 'Latn',
 'ace': 'Latn',
 'ach': 'Latn',
 'ada': 'Latn',
 'ady': 'Cyrl',
 'aeb': 'Arab',
 'af': 'Latn',
 'afr': 'Latn',
 'agq': 'Latn',
 'aii': 'Syrc',
 'ak': 'Latn',
 'aka': 'Latn',
 'akz': 'Latn',
 'ale': 'Latn',
 'aln': 'Latn',
 'alt': 'Cyrl',
 'am': 'Ethi',
 'amh': 'Ethi',
 'amo': 'Latn',
 'an': 'Latn',
 'anp': 'Deva',
 'aoz': 'Latn',
 'apu': 'Latn',
 'ar': 'Arab',
 'ara': 'Arab',
 'arg': 'Latn',
 'arn': 'Latn',
 'aro': 'Latn',
 'arp': 'Latn',
 'arq': 'Arab',
 'ars': 'Arab',
 'ary': 'Arab',
 'arz': 'Arab',
 'as': 'Beng',
 'asa': 'Latn',
 'asm': 'Beng',
 'ast': 'Latn',
 'atj': 'Latn',
 'av': 'Cyrl',
 'ava': 'Cyrl',
 'awa': 'Deva',
 'ay': 'Latn',
 'aym': 'Latn',
 'az': 'Latn',
 'aze': 'Latn',
 'ba': 'Cyrl',
 'bak': 'Cyrl',
 'bal': 'Arab',
 'bam': 'Latn',
 'ban': 'Latn',
 'bap': 'Deva',
 'bar': 'Latn',
 'bas': 'Latn',
 'bax': 'Bamu',
 'bbc': 'Latn',
 'bbj': 'Latn',
 'bci': 'Latn',
 'be': 'Cyrl',
 'bej': 'Arab',
 'bel': 'Cyrl',
 'bem': 'Latn',
 'ben': 'Beng',
 'bew': 'Latn',
 'bez': 'Latn',
 'bfd': 'Latn',
 'bfq': 'Taml',
 'bft': 'Arab',
 'bfy': 'Deva',
 'bg': 'Cyrl',
 'bgc': 'Deva',
 'bgn': 'Arab',
 'bgx': 'Grek',
 'bhb': 'Deva',
 'bhi': 'Deva',
 'bho': 'Deva',
 'bi': 'Latn',
 'bik': 'Latn',
 'bin': 'Latn',
 'bis': 'Latn',
 'bjj': 'Deva',
 'bjn': 'Latn',
 'bkm': 'Latn',
 'bku': 'Latn',
 'bla': 'Cans',
 'blt': 'Tavt',
 'bm': 'Latn',
 'bmq': 'Latn',
 'bn': 'Beng',
 'bo': 'Tibt',
 'bod': 'Tibt',
 'bos': 'Latn',
 'bpy': 'Beng',
 'bqi': 'Arab',
 'bqv': 'Latn',
 'br': 'Latn',
 'bra': 'Deva',
 'bre': 'Latn',
 'brh': 'Arab',
 'brx': 'Deva',
 'bs': 'Latn',
 'bss': 'Latn',
 'bto': 'Latn',
 'btv': 'Deva',
 'bua': 'Cyrl',
 'buc': 'Latn',
 'bug': 'Latn',
 'bul': 'Cyrl',
 'bum': 'Latn',
 'bvb': 'Latn',
 'bxr': 'Cyrl',
 'byn': 'Ethi',
 'byv': 'Latn',
 'bze': 'Latn',
 'bzx': 'Latn',
 'ca': 'Latn',
 'cad': 'Latn',
 'car': 'Latn',
 'cat': 'Latn',
 'cay': 'Latn',
 'cch': 'Latn',
 'ccp': 'Cakm',
 'ce': 'Cyrl',
 'ceb': 'Latn',
 'ces': 'Latn',
 'cgg': 'Latn',
 'ch': 'Latn',
 'cha': 'Latn',
 'che': 'Cyrl',
 'chk': 'Latn',
 'chm': 'Cyrl',
 'cho': 'Latn',
 'chp': 'Latn',
 'chr': 'Cher',
 'chv': 'Cyrl',
 'chy': 'Latn',
 'cic': 'Latn',
 'ciw': 'Latn',
 'cja': 'Arab',
 'cjm': 'Cham',
 'cjs': 'Cyrl',
 'ckb': 'Arab',
 'ckt': 'Cyrl',
 'co': 'Latn',
 'cor': 'Latn',
 'cos': 'Latn',
 'cps': 'Latn',
 'cr': 'Latn',
 'cre': 'Latn',
 'crh': 'Cyrl',
 'crj': 'Latn',
 'crk': 'Latn',
 'crl': 'Latn',
 'crm': 'Cans',
 'crs': 'Latn',
 'cs': 'Latn',
 'csw': 'Cans',
 'ctd': 'Latn',
 'cv': 'Cyrl',
 'cy': 'Latn',
 'cym': 'Latn',
 'da': 'Latn',
 'dak': 'Latn',
 'dan': 'Latn',
 'dar': 'Cyrl',
 'dav': 'Latn',
 'dcc': 'Arab',
 'de': 'Latn',
 'del': 'Latn',
 'den': 'Latn',
 'deu': 'Latn',
 'dgr': 'Latn',
 'din': 'Latn',
 'div': 'Thaa',
 'dje': 'Latn',
 'dng': 'Cyrl',
 'dnj': 'Latn',
 'doi': 'Arab',
 'dsb': 'Latn',
 'dtm': 'Latn',
 'dtp': 'Latn',
 'dty': 'Deva',
 'dua': 'Latn',
 'dv': 'Thaa',
 'dyo': 'Latn',
 'dyu': 'Latn',
 'dz': 'Tibt',
 'dzo': 'Tibt',
 'ebu': 'Latn',
 'ee': 'Latn',
 'efi': 'Latn',
 'egl': 'Latn',
 'eka': 'Latn',
 'eky': 'Kali',
 'el': 'Grek',
 'ell': 'Grek',
 'en': 'Latn',
 'eng': 'Latn',
 'eo': 'Latn',
 'epo': 'Latn',
 'es': 'Latn',
 'ess': 'Latn',
 'est': 'Latn',
 'esu': 'Latn',
 'et': 'Latn',
 'eu': 'Latn',
 'eus': 'Latn',
 'evn': 'Cyrl',
 'ewe': 'Latn',
 'ewo': 'Latn',
 'ext': 'Latn',
 'fa': 'Arab',
 'fan': 'Latn',
 'fao': 'Latn',
 'fas': 'Arab',
 'ff': 'Latn',
 'ffm': 'Latn',
 'fi': 'Latn',
 'fia': 'Arab',
 'fij': 'Latn',
 'fil': 'Latn',
 'fin': 'Latn',
 'fit': 'Latn',
 'fj': 'Latn',
 'fkv': 'Latn',
 'fo': 'Latn',
 'fon': 'Latn',
 'fr': 'Latn',
 'fra': 'Latn',
 'frc': 'Latn',
 'frp': 'Latn',
 'frr': 'Latn',
 'frs': 'Latn',
 'fry': 'Latn',
 'fud': 'Latn',
 'ful': 'Latn',
 'fuq': 'Latn',
 'fur': 'Latn',
 'fuv': 'Latn',
 'fvr': 'Latn',
 'fy': 'Latn',
 'ga': 'Latn',
 'gaa': 'Latn',
 'gag': 'Latn',
 'gan': 'Hans',
 'gay': 'Latn',
 'gba': 'Latn',
 'gbm': 'Deva',
 'gbz': 'Arab',
 'gcr': 'Latn',
 'gd': 'Latn',
 'gil': 'Latn',
 'gjk': 'Arab',
 'gju': 'Arab',
 'gl': 'Latn',
 'gla': 'Latn',
 'gld': 'Cyrl',
 'gle': 'Latn',
 'glg': 'Latn',
 'glk': 'Arab',
 'glv': 'Latn',
 'gn': 'Latn',
 'gom': 'Deva',
 'gon': 'Telu',
 'gor': 'Latn',
 'gos': 'Latn',
 'grb': 'Latn',
 'grn': 'Latn',
 'grt': 'Beng',
 'gsw': 'Latn',
 'gu': 'Gujr',
 'gub': 'Latn',
 'guc': 'Latn',
 'guj': 'Gujr',
 'gur': 'Latn',
 'guz': 'Latn',
 'gv': 'Latn',
 'gvr': 'Deva',
 'gwi': 'Latn',
 'ha': 'Latn',
 'hai': 'Latn',
 'hak': 'Hans',
 'hat': 'Latn',
 'hau': 'Latn',
 'haw': 'Latn',
 'haz': 'Arab',
 'hdn': 'Latn',
 'he': 'Hebr',
 'heb': 'Hebr',
 'her': 'Latn',
 'hi': 'Deva',
 'hif': 'Latn',
 'hil': 'Latn',
 'hin': 'Deva',
 'hmd': 'Plrd',
 'hmn': 'Latn',
 'hmo': 'Latn',
 'hnd': 'Arab',
 'hne': 'Deva',
 'hnj': 'Laoo',
 'hnn': 'Latn',
 'hno': 'Arab',
 'ho': 'Latn',
 'hoc': 'Deva',
 'hoj': 'Deva',
 'hop': 'Latn',
 'hr': 'Latn',
 'hrv': 'Latn',
 'hsb': 'Latn',
 'hsn': 'Hans',
 'ht': 'Latn',
 'hu': 'Latn',
 'hun': 'Latn',
 'hup': 'Latn',
 'hy': 'Armn',
 'hye': 'Armn',
 'hz': 'Latn',
 'iba': 'Latn',
 'ibb': 'Latn',
 'ibo': 'Latn',
 'id': 'Latn',
 'ife': 'Latn',
 'ig': 'Latn',
 'ii': 'Yiii',
 'iii': 'Yiii',
 'ik': 'Latn',
 'ikt': 'Latn',
 'iku': 'Latn',
 'ilo': 'Latn',
 'ind': 'Latn',
 'inh': 'Cyrl',
 'ipk': 'Latn',
 'is': 'Latn',
 'isl': 'Latn',
 'it': 'Latn',
 'ita': 'Latn',
 'iu': 'Latn',
 'izh': 'Latn',
 'ja': 'Jpan',
 'jam': 'Latn',
 'jav': 'Latn',
 'jgo': 'Latn',
 'jmc': 'Latn',
 'jml': 'Deva',
 'jpn': 'Jpan',
 'jpr': 'Hebr',
 'jrb': 'Hebr',
 'jv': 'Latn',
 'ka': 'Geor',
 'kaa': 'Cyrl',
 'kab': 'Latn',
 'kac': 'Latn',
 'kaj': 'Latn',
 'kal': 'Latn',
 'kam': 'Latn',
 'kan': 'Knda',
 'kao': 'Latn',
 'kas': 'Deva',
 'kat': 'Geor',
 'kau': 'Latn',
 'kaz': 'Cyrl',
 'kbd': 'Cyrl',
 'kca': 'Cyrl',
 'kcg': 'Latn',
 'kck': 'Latn',
 'kde': 'Latn',
 'kdt': 'Thai',
 'kea': 'Latn',
 'kek': 'Latn',
 'kfo': 'Latn',
 'kfr': 'Deva',
 'kfy': 'Deva',
 'kg': 'Latn',
 'kge': 'Latn',
 'kgp': 'Latn',
 'kha': 'Latn',
 'khb': 'Talu',
 'khk': 'Cyrl',
 'khm': 'Khmr',
 'khn': 'Deva',
 'khq': 'Latn',
 'kht': 'Mymr',
 'khw': 'Arab',
 'ki': 'Latn',
 'kik': 'Latn',
 'kin': 'Latn',
 'kio': 'Latn',
 'kir': 'Latn',
 'kiu': 'Latn',
 'kj': 'Latn',
 'kjg': 'Laoo',
 'kjh': 'Cyrl',
 'kk': 'Cyrl',
 'kkj': 'Latn',
 'kl': 'Latn',
 'kln': 'Latn',
 'km': 'Khmr',
 'kmb': 'Latn',
 'kn': 'Knda',
 'ko': 'Kore',
 'koi': 'Cyrl',
 'kok': 'Deva',
 'kom': 'Cyrl',
 'kon': 'Latn',
 'kor': 'Kore',
 'kos': 'Latn',
 'kpe': 'Latn',
 'kpv': 'Cyrl',
 'kpy': 'Cyrl',
 'kr': 'Latn',
 'krc': 'Cyrl',
 'kri': 'Latn',
 'krj': 'Latn',
 'krl': 'Latn',
 'kru': 'Deva',
 'ks': 'Deva',
 'ksb': 'Latn',
 'ksf': 'Latn',
 'ksh': 'Latn',
 'ku': 'Latn',
 'kua': 'Latn',
 'kum': 'Cyrl',
 'kur': 'Latn',
 'kut': 'Latn',
 'kv': 'Cyrl',
 'kvr': 'Latn',
 'kvx': 'Arab',
 'kw': 'Latn',
 'kxm': 'Thai',
 'kxp': 'Arab',
 'ky': 'Latn',
 'kyu': 'Kali',
 'la': 'Latn',
 'lad': 'Hebr',
 'lag': 'Latn',
 'lah': 'Arab',
 'laj': 'Latn',
 'lam': 'Latn',
 'lao': 'Laoo',
 'lat': 'Latn',
 'lav': 'Latn',
 'lb': 'Latn',
 'lbe': 'Cyrl',
 'lbw': 'Latn',
 'lcp': 'Thai',
 'lep': 'Lepc',
 'lez': 'Cyrl',
 'lg': 'Latn',
 'li': 'Latn',
 'lif': 'Limb',
 'lij': 'Latn',
 'lim': 'Latn',
 'lin': 'Latn',
 'lis': 'Lisu',
 'lit': 'Latn',
 'liv': 'Latn',
 'ljp': 'Latn',
 'lki': 'Arab',
 'lkt': 'Latn',
 'lmn': 'Telu',
 'lmo': 'Latn',
 'ln': 'Latn',
 'lo': 'Laoo',
 'lol': 'Latn',
 'loz': 'Latn',
 'lrc': 'Arab',
 'lt': 'Latn',
 'ltg': 'Latn',
 'ltz': 'Latn',
 'lu': 'Latn',
 'lua': 'Latn',
 'lub': 'Latn',
 'lug': 'Latn',
 'lun': 'Latn',
 'luo': 'Latn',
 'lus': 'Beng',
 'lut': 'Latn',
 'luy': 'Latn',
 'luz': 'Arab',
 'lv': 'Latn',
 'lwl': 'Thai',
 'lzz': 'Latn',
 'mad': 'Latn',
 'maf': 'Latn',
 'mag': 'Deva',
 'mah': 'Latn',
 'mai': 'Deva',
 'mak': 'Latn',
 'mal': 'Mlym',
 'man': 'Nkoo',
 'mar': 'Deva',
 'mas': 'Latn',
 'maz': 'Latn',
 'mdf': 'Cyrl',
 'mdh': 'Latn',
 'mdr': 'Latn',
 'mdt': 'Latn',
 'men': 'Latn',
 'mer': 'Latn',
 'mfa': 'Arab',
 'mfe': 'Latn',
 'mg': 'Latn',
 'mgh': 'Latn',
 'mgo': 'Latn',
 'mgp': 'Deva',
 'mgy': 'Latn',
 'mh': 'Latn',
 'mhr': 'Cyrl',
 'mi': 'Latn',
 'mic': 'Latn',
 'min': 'Latn',
 'mk': 'Cyrl',
 'mkd': 'Cyrl',
 'ml': 'Mlym',
 'mlg': 'Latn',
 'mls': 'Latn',
 'mlt': 'Latn',
 'mn': 'Cyrl',
 'mni': 'Beng',
 'mns': 'Cyrl',
 'mnw': 'Mymr',
 'moe': 'Latn',
 'moh': 'Latn',
 'mon': 'Cyrl',
 'mos': 'Latn',
 'mr': 'Deva',
 'mrd': 'Deva',
 'mri': 'Latn',
 'mrj': 'Cyrl',
 'mro': 'Latn',
 'ms': 'Latn',
 'msa': 'Latn',
 'mt': 'Latn',
 'mtr': 'Deva',
 'mua': 'Latn',
 'mus': 'Latn',
 'mvy': 'Arab',
 'mwk': 'Latn',
 'mwl': 'Latn',
 'mwr': 'Deva',
 'mwv': 'Latn',
 'mxc': 'Latn',
 'my': 'Mymr',
 'mya': 'Mymr',
 'myv': 'Cyrl',
 'myx': 'Latn',
 'mzn': 'Arab',
 'na': 'Latn',
 'nan': 'Hans',
 'nap': 'Latn',
 'naq': 'Latn',
 'nau': 'Latn',
 'nav': 'Latn',
 'nb': 'Latn',
 'nbl': 'Latn',
 'nch': 'Latn',
 'nd': 'Latn',
 'ndc': 'Latn',
 'nde': 'Latn',
 'ndl': 'Latn',
 'ndo': 'Latn',
 'nds': 'Latn',
 'ne': 'Deva',
 'nep': 'Deva',
 'new': 'Deva',
 'ng': 'Latn',
 'ngl': 'Latn',
 'nhe': 'Latn',
 'nhw': 'Latn',
 'nia': 'Latn',
 'nij': 'Latn',
 'nio': 'Cyrl',
 'niu': 'Latn',
 'njo': 'Latn',
 'nl': 'Latn',
 'nld': 'Latn',
 'nmg': 'Latn',
 'nn': 'Latn',
 'nnh': 'Latn',
 'nno': 'Latn',
 'no': 'Latn',
 'nob': 'Latn',
 'nod': 'Lana',
 'noe': 'Deva',
 'nog': 'Cyrl',
 'non': 'Runr',
 'nor': 'Latn',
 'nqo': 'Nkoo',
 'nr': 'Latn',
 'nsk': 'Cans',
 'nso': 'Latn',
 'nus': 'Latn',
 'nv': 'Latn',
 'nxq': 'Latn',
 'ny': 'Latn',
 'nya': 'Latn',
 'nym': 'Latn',
 'nyn': 'Latn',
 'nyo': 'Latn',
 'nzi': 'Latn',
 'oc': 'Latn',
 'oci': 'Latn',
 'oj': 'Latn',
 'oji': 'Latn',
 'olo': 'Latn',
 'om': 'Latn',
 'or': 'Orya',
 'ori': 'Orya',
 'orm': 'Latn',
 'os': 'Cyrl',
 'osa': 'Osge',
 'oss': 'Cyrl',
 'pa': 'Guru',
 'pag': 'Latn',
 'pam': 'Latn',
 'pan': 'Guru',
 'pap': 'Latn',
 'pau': 'Latn',
 'pcd': 'Latn',
 'pcm': 'Latn',
 'pdc': 'Latn',
 'pdt': 'Latn',
 'pfl': 'Latn',
 'pko': 'Latn',
 'pl': 'Latn',
 'pms': 'Latn',
 'pnt': 'Latn',
 'pol': 'Latn',
 'pon': 'Latn',
 'por': 'Latn',
 'prd': 'Arab',
 'prs': 'Arab',
 'ps': 'Arab',
 'pt': 'Latn',
 'pus': 'Arab',
 'puu': 'Latn',
 'qu': 'Latn',
 'quc': 'Latn',
 'que': 'Latn',
 'qug': 'Latn',
 'quz': 'Latn',
 'raj': 'Deva',
 'rap': 'Latn',
 'rar': 'Latn',
 'rcf': 'Latn',
 'rej': 'Latn',
 'rgn': 'Latn',
 'ria': 'Latn',
 'rif': 'Tfng',
 'rjs': 'Deva',
 'rkt': 'Beng',
 'rm': 'Latn',
 'rmf': 'Latn',
 'rmn': 'Latn',
 'rmo': 'Latn',
 'rmt': 'Arab',
 'rmu': 'Latn',
 'rmy': 'Latn',
 'rn': 'Latn',
 'rng': 'Latn',
 'ro': 'Latn',
 'rob': 'Latn',
 'rof': 'Latn',
 'roh': 'Latn',
 'rom': 'Latn',
 'ron': 'Latn',
 'rtm': 'Latn',
 'ru': 'Cyrl',
 'rue': 'Cyrl',
 'rug': 'Latn',
 'run': 'Latn',
 'rup': 'Latn',
 'rus': 'Cyrl',
 'rw': 'Latn',
 'rwk': 'Latn',
 'ryu': 'Kana',
 'sa': 'Deva',
 'sad': 'Latn',
 'saf': 'Latn',
 'sag': 'Latn',
 'sah': 'Cyrl',
 'san': 'Deva',
 'saq': 'Latn',
 'sas': 'Latn',
 'sat': 'Olck',
 'saz': 'Saur',
 'sbp': 'Latn',
 'sc': 'Latn',
 'sck': 'Deva',
 'scn': 'Latn',
 'sco': 'Latn',
 'scs': 'Latn',
 'sd': 'Deva',
 'sdc': 'Latn',
 'sdh': 'Arab',
 'se': 'Latn',
 'see': 'Latn',
 'sef': 'Latn',
 'seh': 'Latn',
 'sei': 'Latn',
 'sel': 'Cyrl',
 'ses': 'Latn',
 'sg': 'Latn',
 'sgs': 'Latn',
 'shi': 'Tfng',
 'shn': 'Mymr',
 'si': 'Sinh',
 'sid': 'Latn',
 'sin': 'Sinh',
 'sjd': 'Cyrl',
 'sje': 'Latn',
 'sjt': 'Cyrl',
 'sk': 'Latn',
 'skr': 'Arab',
 'sl': 'Latn',
 'sli': 'Latn',
 'slk': 'Latn',
 'slv': 'Latn',
 'sly': 'Latn',
 'sm': 'Latn',
 'sma': 'Latn',
 'sme': 'Latn',
 'smj': 'Latn',
 'smn': 'Latn',
 'smo': 'Latn',
 'sms': 'Latn',
 'sn': 'Latn',
 'sna': 'Latn',
 'snd': 'Deva',
 'snk': 'Latn',
 'so': 'Latn',
 'som': 'Latn',
 'sot': 'Latn',
 'sou': 'Thai',
 'spa': 'Latn',
 'sq': 'Latn',
 'sqi': 'Latn',
 'sr': 'Latn',
 'srb': 'Latn',
 'srd': 'Latn',
 'srn': 'Latn',
 'srp': 'Latn',
 'srr': 'Latn',
 'srs': 'Latn',
 'srx': 'Deva',
 'ss': 'Latn',
 'ssw': 'Latn',
 'ssy': 'Latn',
 'st': 'Latn',
 'sto': 'Latn',
 'stq': 'Latn',
 'su': 'Latn',
 'suk': 'Latn',
 'sun': 'Latn',
 'sus': 'Latn',
 'sv': 'Latn',
 'sw': 'Latn',
 'swa': 'Latn',
 'swb': 'Arab',
 'swe': 'Latn',
 'swg': 'Latn',
 'swv': 'Deva',
 'sxn': 'Latn',
 'syi': 'Latn',
 'syl': 'Beng',
 'syr': 'Syrc',
 'szl': 'Latn',
 'ta': 'Taml',
 'tab': 'Cyrl',
 'tah': 'Latn',
 'taj': 'Deva',
 'tam': 'Taml',
 'tat': 'Cyrl',
 'tau': 'Latn',
 'tbw': 'Latn',
 'tcy': 'Knda',
 'tdd': 'Tale',
 'tdg': 'Deva',
 'tdh': 'Deva',
 'te': 'Telu',
 'tel': 'Telu',
 'tem': 'Latn',
 'teo': 'Latn',
 'ter': 'Latn',
 'tet': 'Latn',
 'tg': 'Latn',
 'tgk': 'Latn',
 'tgl': 'Latn',
 'th': 'Thai',
 'tha': 'Thai',
 'thl': 'Deva',
 'thq': 'Deva',
 'thr': 'Deva',
 'ti': 'Ethi',
 'tig': 'Ethi',
 'tir': 'Ethi',
 'tiv': 'Latn',
 'tk': 'Latn',
 'tkl': 'Latn',
 'tkr': 'Latn',
 'tkt': 'Deva',
 'tku': 'Latn',
 'tl': 'Latn',
 'tlh': 'Piqd',
 'tli': 'Latn',
 'tly': 'Latn',
 'tmh': 'Latn',
 'tn': 'Latn',
 'to': 'Latn',
 'tog': 'Latn',
 'ton': 'Latn',
 'tpi': 'Latn',
 'tr': 'Latn',
 'tru': 'Latn',
 'trv': 'Latn',
 'trw': 'Arab',
 'ts': 'Latn',
 'tsd': 'Grek',
 'tsg': 'Latn',
 'tsi': 'Latn',
 'tsj': 'Tibt',
 'tsn': 'Latn',
 'tso': 'Latn',
 'tt': 'Cyrl',
 'ttj': 'Latn',
 'tts': 'Thai',
 'ttt': 'Latn',
 'tuk': 'Latn',
 'tum': 'Latn',
 'tur': 'Latn',
 'tuv': 'Latn',
 'tvl': 'Latn',
 'twq': 'Latn',
 'ty': 'Latn',
 'tyv': 'Cyrl',
 'tzm': 'Tfng',
 'ude': 'Cyrl',
 'udm': 'Cyrl',
 'ug': 'Cyrl',
 'uig': 'Cyrl',
 'uk': 'Cyrl',
 'ukr': 'Cyrl',
 'uli': 'Latn',
 'umb': 'Latn',
 'unr': 'Deva',
 'unx': 'Deva',
 'ur': 'Arab',
 'urd': 'Arab',
 'uz': 'Latn',
 'uzb': 'Latn',
 'vai': 'Vaii',
 've': 'Latn',
 'vec': 'Latn',
 'ven': 'Latn',
 'vep': 'Latn',
 'vi': 'Latn',
 'vic': 'Latn',
 'vie': 'Latn',
 'vls': 'Latn',
 'vmf': 'Latn',
 'vmw': 'Latn',
 'vot': 'Latn',
 'vro': 'Latn',
 'vun': 'Latn',
 'wa': 'Latn',
 'wae': 'Latn',
 'wal': 'Ethi',
 'war': 'Latn',
 'was': 'Latn',
 'wbp': 'Latn',
 'wbq': 'Telu',
 'wbr': 'Deva',
 'wln': 'Latn',
 'wls': 'Latn',
 'wni': 'Arab',
 'wo': 'Latn',
 'wol': 'Latn',
 'wtm': 'Deva',
 'wuu': 'Hans',
 'xal': 'Cyrl',
 'xav': 'Latn',
 'xh': 'Latn',
 'xho': 'Latn',
 'xmf': 'Geor',
 'xnr': 'Deva',
 'xog': 'Latn',
 'xsr': 'Deva',
 'xwo': 'Mong',
 'yao': 'Latn',
 'yap': 'Latn',
 'yav': 'Latn',
 'ybb': 'Latn',
 'yi': 'Hebr',
 'yid': 'Hebr',
 'yo': 'Latn',
 'yor': 'Latn',
 'yrk': 'Cyrl',
 'yrl': 'Latn',
 'yua': 'Latn',
 'yue': 'Hant',
 'za': 'Latn',
 'zag': 'Latn',
 'zap': 'Latn',
 'zdj': 'Arab',
 'zea': 'Latn',
 'zgh': 'Tfng',
 'zh': 'Hant',
 'zha': 'Latn',
 'zho': 'Hant',
 'zmi': 'Latn',
 'zu': 'Latn',
 'zul': 'Latn',
 'zun': 'Latn',
 'zza': 'Latn'}
